@@ -6,8 +6,8 @@
 ;; Author: Campbell Barton <ideasman42@gmail.com>
 
 ;; URL: https://codeberg.org/ideasman42/emacs-utimeclock
-;; Package-Version: 20250913.2251
-;; Package-Revision: a3022c1d4c69
+;; Package-Version: 20251126.346
+;; Package-Revision: ae0659efff1e
 ;; Package-Requires: ((emacs "29.1"))
 
 ;;; Commentary:
@@ -383,7 +383,7 @@ accumulating all times in the buffer."
                  (line (utimeclock-extract-line-multi time-pos-next prefix)))
 
             (pcase-let ((`(,time-as-seconds . ,is-incomplete)
-                         (utimeclock-accumulate-line line (not time-was-incomplete-all))))
+                         (utimeclock-accumulate-line line (null time-was-incomplete-all))))
               (when is-incomplete
                 (setq time-was-incomplete-all t))
               (incf time-as-seconds-all time-as-seconds)))
